function params=defaults
% defaults.m creates a parameters data structure
% params=defaults() takes no input parameters.  It creates the data 
% structure with every field initialized to default values.
% It may also be called to reset the parameters data
% structure fields to their default values. See m-file for current
% default values.
%
% Parameters data structure:
% params.playdevice     play device number used by pa_wavplay drivers
% params.recdevice      record device number used by pa_wavplay drivers
% params.devicetype     device type used by pa_wavplay drivers
% params.fsamp          sampling rate for play and record
% params.nchan          number of record channels
% params.firstchan      channel number of first record channel
%                       other channels are consecutive
% params.latency        Approximate delay of played samples relative
%                       to recorded samples in seconds.
%                       This must be measured and set correctly.
% params.micscale       distance from first mic to last mic in meters
% params.miclocs        Row vector of dimensionless mic locations.  Must
%                       start with 0.0, end with 1.0, and must have
%                       params.nchan elements
% params.micoffset      distance in meters from fiducial plane to first mic

% set default values
params.playdevice=0;       % device number used by pa_wavplay drivers
params.recdevice=0;        % device number used by pa_wavplay drivers
params.devicetype='asio';  % device type used by pa_wavplay
params.fsamp=44100;   % sampling rate for play and record
params.nchan=6;       % number of record channels
params.firstchan=3;   % channel number of first channel
params.latency=0.038; % Approximate delay of played samples relative
                      % to recorded samples in seconds.  This must be 
                      % measured and set correctly
params.micscale=0.300;    % distance from first mic to last mic in meters
params.miclocs=[0.0 0.078205 0.279317 0.439589 0.678611 1.00];  
                      % vector of dimensionless microphone locations
params.micoffset=0.050;  % distance in meters from fiducial plane 
                         % to first mic
