function recordseries=playrecord(params,playseries)
% recordseries=playrecord(params,playseries) plays a time series and records
% multiple channels simultaneously, with time-shifting to correct
% for the play latency delay.
%
% Inputs:
% params                  Parameters data structure, see defaults.m
%                         for details.
% playseries.samples      Time-series column vector to play.
% playseries.times        Column vector containing the time of each
%                         sample, starting at time=0.
%
% Outputs:
% recordseries.samples    Recorded samples corrected for latency
%                         with one column for each channel.
%                         Number of samples per channel is same
%                         as number of samples in playseries.
%                         Number of channels is determied by
%                         params.nchan.
% recordseries.times      Column vector containing the time of each
%                         sample, starting at time=0.
%
% Note that play and record sampling rates are determined by params.fsamp,
% not by the .times fields.  The .times fields are included in time-series
% data structures as a convenience for plotting and are created using the 
% current sampling rate.

nsamp=size(playseries.samples,1);      % find number of samples in playseries
nsamplatent = round(params.latency*params.fsamp);  % number of samples in latency time
recordseries.times = (0:nsamp-1)'/params.fsamp;    % recordseries times

% play and record, record nsamplatent extra samples to cover latency time
recordbuffer = pa_wavplayrecord(playseries.samples,params.playdevice,...
         params.fsamp,nsamp+nsamplatent,...
         params.firstchan,params.firstchan+params.nchan-1,...
         params.recdevice,params.devicetype);
recordseries.samples = recordbuffer(nsamplatent+1:end,:);  % remove empty part due to latency
%
% For testing code when audio hardware is not available, comment out
% previous two commands (5 lines) and replace with next 4 lines:
%   recordseries.samples=zeros(nsamp,params.nchan);
%   for n=1:params.nchan
%     recordseries.samples(:,n)=(1.0+0.1*(n-1)).*playseries.samples;
%   end